@@ -1,3 +1,4 @@
+import os
 import sys
 
 from boostedblob.cli import run_bbb
@@ -7,6 +8,8 @@ def main() -> None:
     try:
         run_bbb(sys.argv[1:])
     except Exception:
+        if os.environ.get("BBB_TRACEBACK"):
+            raise
         sys.exit(1)
 
 
